loading constant
String
const loading
Spinner-style symbol shown in front of a message while a step is in progress.
Implementation
static const String loading = ' ↻ ';
Spinner-style symbol shown in front of a message while a step is in progress.
static const String loading = ' ↻ ';