question constant
String
const question
Question mark shown in front of a prompt that's waiting on user input.
Implementation
static const String question = ' ? ';
Question mark shown in front of a prompt that's waiting on user input.
static const String question = ' ? ';