rocket constant
String
const rocket
Sparkle symbol used to highlight a big action, like scaffolding a new project.
Implementation
static const String rocket = ' ✧ ';
Sparkle symbol used to highlight a big action, like scaffolding a new project.
static const String rocket = ' ✧ ';