success constant
String
const success
Checkmark shown in front of a message when something completed successfully.
Implementation
static const String success = ' ✔ ';
Checkmark shown in front of a message when something completed successfully.
static const String success = ' ✔ ';