SgConfig class

The parsed contents of a project's sg_cli.yaml config file.

Constructors

SgConfig({required String version, required List<String> routePaths})
Creates a config from an already-parsed version and routePaths.

Properties

hashCode int
The hash code for this object.
no setterinherited
routePaths List<String>
The route paths new screens should be registered under when running create commands.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
Which architecture version this project uses: max, bronze, or amber.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited