error static method
Prints message with an error symbol in front of it.
Implementation
static void error(String message) => _print(ConsoleSymbols.error, message);
Prints message with an error symbol in front of it.
static void error(String message) => _print(ConsoleSymbols.error, message);