package static method
Prints message with a package symbol in front of it.
Implementation
static void package(String message) => _print(ConsoleSymbols.package, message);
Prints message with a package symbol in front of it.
static void package(String message) => _print(ConsoleSymbols.package, message);