utils/pubspec_helper library
Functions
-
getModuleName(
) → String -
Reads the
name:field from the project'spubspec.yaml. Returns an empty string if the file is missing or has noname:field.
name: field from the project's pubspec.yaml. Returns an empty string if the file is missing or has no name: field.