arrowDown constant
String
const arrowDown
Down-pointing arrow used to show a decrease or downward movement.
Implementation
static const String arrowDown = ' ↓ ';
Down-pointing arrow used to show a decrease or downward movement.
static const String arrowDown = ' ↓ ';