arrowLeft constant
String
const arrowLeft
Left-pointing arrow used to show direction or a previous step.
Implementation
static const String arrowLeft = ' ← ';
Left-pointing arrow used to show direction or a previous step.
static const String arrowLeft = ' ← ';