arrowRight constant
String
const arrowRight
Right-pointing arrow used to show direction or a next step.
Implementation
static const String arrowRight = ' → ';
Right-pointing arrow used to show direction or a next step.
static const String arrowRight = ' → ';