arrowUp constant
String
const arrowUp
Up-pointing arrow used to show an increase or upward movement.
Implementation
static const String arrowUp = ' ↑ ';
Up-pointing arrow used to show an increase or upward movement.
static const String arrowUp = ' ↑ ';