clipboard constant
String
const clipboard
Clipboard icon used in front of a summary or checklist.
Implementation
static const String clipboard = ' 📋 ';
Clipboard icon used in front of a summary or checklist.
static const String clipboard = ' 📋 ';