five constant
String
const five
Numbered "5" icon for the fifth step in a numbered list.
Implementation
static const String five = ' 5️⃣ ';
Numbered "5" icon for the fifth step in a numbered list.
static const String five = ' 5️⃣ ';