four constant
String
const four
Numbered "4" icon for the fourth step in a numbered list.
Implementation
static const String four = ' 4️⃣ ';
Numbered "4" icon for the fourth step in a numbered list.
static const String four = ' 4️⃣ ';