globe constant
String
const globe
Globe icon used in front of network or internet-related messages.
Implementation
static const String globe = ' 🌐 ';
Globe icon used in front of network or internet-related messages.
static const String globe = ' 🌐 ';