hourglass constant
String
const hourglass
Hourglass icon used while waiting on a slower step.
Implementation
static const String hourglass = ' ⏳ ';
Hourglass icon used while waiting on a slower step.
static const String hourglass = ' ⏳ ';