key constant
String
const key
Key icon used in front of credential or API-key related messages.
Implementation
static const String key = ' 🔑 ';
Key icon used in front of credential or API-key related messages.
static const String key = ' 🔑 ';