medal constant
String
const medal
Medal icon, an alternate way to celebrate a completed step.
Implementation
static const String medal = ' 🥇 ';
Medal icon, an alternate way to celebrate a completed step.
static const String medal = ' 🥇 ';