note constant
String
const note
Notepad icon used in front of a note to the user.
Implementation
static const String note = ' 📝 ';
Notepad icon used in front of a note to the user.
static const String note = ' 📝 ';