one constant
String
const one
Numbered "1" icon for the first step in a numbered list.
Implementation
static const String one = ' 1️⃣ ';
Numbered "1" icon for the first step in a numbered list.
static const String one = ' 1️⃣ ';