party constant
String
const party
Party popper icon used to celebrate a completed setup.
Implementation
static const String party = ' 🎉 ';
Party popper icon used to celebrate a completed setup.
static const String party = ' 🎉 ';