question constant
String
const question
Question mark icon used in front of prompts or help text.
Implementation
static const String question = ' ❓ ';
Question mark icon used in front of prompts or help text.
static const String question = ' ❓ ';