refresh constant
String
const refresh
Refresh icon, an alternate loading symbol for retried steps.
Implementation
static const String refresh = ' 🔄 ';
Refresh icon, an alternate loading symbol for retried steps.
static const String refresh = ' 🔄 ';