rocket constant
String
const rocket
Rocket icon used when kicking off a big action, like scaffolding a project.
Implementation
static const String rocket = ' 🚀 ';
Rocket icon used when kicking off a big action, like scaffolding a project.
static const String rocket = ' 🚀 ';