sparkles constant
String
const sparkles
Sparkles icon used to highlight a freshly generated result.
Implementation
static const String sparkles = ' ✨ ';
Sparkles icon used to highlight a freshly generated result.
static const String sparkles = ' ✨ ';