target constant
String
const target
Target icon used to point out the goal of a step.
Implementation
static const String target = ' 🎯 ';
Target icon used to point out the goal of a step.
static const String target = ' 🎯 ';