terminal constant
String
const terminal
Keyboard icon used in front of terminal or command-related messages.
Implementation
static const String terminal = ' ⌨️ ';
Keyboard icon used in front of terminal or command-related messages.
static const String terminal = ' ⌨️ ';