two constant
String
const two
Numbered "2" icon for the second step in a numbered list.
Implementation
static const String two = ' 2️⃣ ';
Numbered "2" icon for the second step in a numbered list.
static const String two = ' 2️⃣ ';