ConsoleSymbols class
Essential console symbols with consistent spacing for clean CLI output
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- books → const String
- Bullet used for list-style output, such as documentation links.
- bulb → const String
- Sparkle symbol used in front of tips or suggestions.
- clipboard → const String
- Bullet used for list-style output, such as a summary of created files.
- error → const String
- "x" shown in front of an error message.
- info → const String
- "i" icon shown in front of a plain informational message.
- loading → const String
- Spinner-style symbol shown in front of a message while a step is in progress.
- package → const String
- Box icon shown in front of messages about packages or dependencies.
- question → const String
- Question mark shown in front of a prompt that's waiting on user input.
- rocket → const String
- Sparkle symbol used to highlight a big action, like scaffolding a new project.
- success → const String
- Checkmark shown in front of a message when something completed successfully.
- warning → const String
- Warning triangle shown in front of a message that needs attention but isn't an error.