ConsoleSymbols class

Essential console symbols with consistent spacing for clean CLI output

Constructors

ConsoleSymbols()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

message(String symbol, String text) String
Helper method for creating custom symbol messages

Constants

books → const String
bulb → const String
clipboard → const String
error → const String
info → const String
loading → const String
package → const String
question → const String
rocket → const String
success → const String
warning → const String