ConsoleLogger class
Simplified console printing utility for consistent formatting
This class provides a unified way to handle console output in the SG CLI, focusing on the essential message types: success, error, warning, info, and loading.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
blank(
) → void -
divider(
{String title = ''}) → void -
error(
String message) → void -
info(
String message) → void -
list(
List< String> items, {String bullet = '•'}) → void -
loading(
String message) → void -
package(
String message) → void -
raw(
String message) → void -
success(
String message) → void -
warning(
String message) → void