ConsoleSymbols class

Console symbols and emojis with proper spacing for clean output Each symbol has 2 spaces on the left and right for better readability

Constructors

ConsoleSymbols()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom(String emoji) String
Helper method to create custom symbol with proper spacing
message(String symbol, String text) String
Create a formatted message with symbol

Constants

android → const String
apple → const String
arrowDown → const String
arrowLeft → const String
arrowRight → const String
arrowUp → const String
books → const String
box → const String
bug → const String
bulb → const String
checkmark → const String
clipboard → const String
cloud → const String
code → const String
cross → const String
dialog → const String
document → const String
error → const String
exclamation → const String
file → const String
fire → const String
five → const String
folder → const String
four → const String
gear → const String
globe → const String
hammer → const String
hourglass → const String
id → const String
info → const String
key → const String
loading → const String
medal → const String
mobile → const String
note → const String
one → const String
package → const String
party → const String
pin → const String
question → const String
refresh → const String
robot → const String
rocket → const String
satellite → const String
sparkles → const String
star → const String
success → const String
tag → const String
target → const String
terminal → const String
three → const String
trophy → const String
two → const String
warning → const String
wrench → const String